@@ -1,5 +1,4 @@
-from pyametista.engine.bands.elements import (process_graphic_element,
-                                              process_report_element)
+from pyametista.engine.bands.elements import process_graphic_element, process_report_element
 from pyametista.engine.commonutilities import add_attr2attributes
 from reportlab.lib import colors
 
@@ -45,7 +44,9 @@ def draw_line(report, x1, y1, x2, y2, line_style, line_width, line_color):
     if line_color is not None:
         report["canvas"].setStrokeColor(colors.HexColor(line_color))
 
-    if line_style != "Double":  # double line consists of wide solid line with thin white line in between
+    if (
+        line_style != "Double"
+    ):  # double line consists of wide solid line with thin white line in between
         report["canvas"].setLineWidth(line_width)
         report["canvas"].line(x1, y1, x2, y2)
     else:
